==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci de le rendre unique.",
    "Password is present in compromised password list. Please choose a different password." : "Le mot de passe est présent dans la liste des mots de passe compromis. Merci d'en choisir un autre.",
    "Password policy" : "Politique de mots de passe",
    "Allows admins to configure a password policy" : "Permet aux administrateurs de configurer une politique de mot de passe.",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permettre à l'administrateur de définir certaines conditions préalables pour le mot de passe, par exemple, imposer une longueur minimale.",
    "Minimal length" : "Taille minimale",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwned.com",
    "Password need to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password need to contain at least one lower case character and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password need to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password need to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci d'en choisir un autre.",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwnd. com"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci de le rendre unique.",
    "Password is present in compromised password list. Please choose a different password." : "Le mot de passe est présent dans la liste des mots de passe compromis. Merci d'en choisir un autre.",
    "Password policy" : "Politique de mots de passe",
    "Allows admins to configure a password policy" : "Permet aux administrateurs de configurer une politique de mot de passe.",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permettre à l'administrateur de définir certaines conditions préalables pour le mot de passe, par exemple, imposer une longueur minimale.",
    "Minimal length" : "Taille minimale",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cette vérification crée un hachage du mot de passe et envoie les 5 premiers caractères de ce hachage à l'API haveibeenpwned.com pour récupérer une liste de tous les hachages qui commencent par ceux-là. Ensuite, il vérifie sur l'instance Nextcloud si le mot de passe est dans le jeu de résultats.",
    "Password need to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password need to contain at least one lower case character and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password need to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password need to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci d'en choisir un autre.",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwnd. com"
},
"nplurals=2; plural=(n > 1);");
